
package de.codedo.conflicteditor;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.apache.http.HttpEntity;
import org.apache.http.HttpHeaders;
import org.apache.http.HttpMessage;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpDelete;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.protocol.HTTP;

public class HttpClientHttpAccess extends Object implements HttpAccess
{
    private String _url;
    private HttpClient _httpClient;

    public HttpClientHttpAccess(URL url)
    {
        super();
        _url = url.toExternalForm();
        _httpClient = new DefaultHttpClient();
    }

    @Override
    public InputStream delete() throws IOException
    {
        HttpDelete delete = new HttpDelete(_url);
        return execute(delete);
    }

    @Override
    public InputStream get() throws IOException
    {
        HttpGet get = new HttpGet(_url);
        return execute(get);
    }

    @Override
    public InputStream post(String content) throws IOException
    {
        HttpEntity entity = new StringEntity(content, HTTP.UTF_8);

        HttpPost post = new HttpPost(_url);
        post.setEntity(entity);
        addJsonContentTypeHeader(post);

        return execute(post);
    }

    @Override
    public InputStream put(String content) throws IOException
    {
        HttpEntity entity = new StringEntity(content, HTTP.UTF_8);

        HttpPut put = new HttpPut(_url);
        put.setEntity(entity);
        addJsonContentTypeHeader(put);

        return execute(put);
    }

    private void addJsonContentTypeHeader(HttpMessage message)
    {
        message.addHeader(HttpHeaders.CONTENT_TYPE, "application/json");
    }

    private InputStream execute(HttpUriRequest request) throws IOException
    {
        HttpResponse response = _httpClient.execute(request);
        HttpEntity entity = response.getEntity();
        return entity.getContent();
    }
}
